@@ -6,7 +6,7 @@ Dancer::Session::DBIC - DBIx::Class session engine for Dancer
 
 =head1 VERSION
 
-0.004
+0.005
 
 =head1 DESCRIPTION
 
@@ -32,7 +32,13 @@ Example configuration:
       data_column: "my_session_data" # defaults to session_data
 
 In conjunction with L<Dancer::Plugin::DBIC>, you can simply use the schema
-object provided by this plugin in your application:
+object provided by this plugin in your application, either by
+providing the name of the schema used by the plugin in the config:
+
+    session_options:
+        schema: default
+
+Or by passing the schema object directly in the code:
 
     set session_options => {schema => schema};
 
@@ -50,6 +56,42 @@ A timestamp field that updates when a session is updated is recommended, so you
 
 This session engine will not automagically remove expired sessions on the server, but with a timestamp field as above, you should be able to to do this manually.
 
+=head1 RESULT CLASS EXAMPLE
+
+This result class would work as-is with the default values of C<session_options>.
+It uses L<DBIx::Class::TimeStamp> to auto-set the C<created>
+and C<last_modified> timestamps.
+
+    package MySchema::Result::Session;
+
+    use strict;
+    use warnings;
+
+    use base 'DBIx::Class::Core';
+
+    __PACKAGE__->load_components(qw(TimeStamp));
+
+    __PACKAGE__->table('sessions');
+
+    __PACKAGE__->add_columns(
+        sessions_id => {
+            data_type => 'varchar', size => 255
+        },
+        session_data => {
+            data_type => 'text'
+        },
+        created => {
+            data_type => 'datetime', set_on_create => 1
+        },
+        last_modified => {
+            data_type => 'datetime', set_on_create => 1, set_on_update => 1
+        },
+    );
+
+    __PACKAGE__->set_primary_key('sessions_id');
+
+    1;
+
 =cut
 
 use strict;
@@ -61,7 +103,7 @@ use Try::Tiny;
 use Module::Load;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 my %dbic_handles;
 
@@ -170,12 +212,17 @@ sub _dbic {
     my $settings = setting('session_options');
 
     # Prefer an active schema over a schema class.
-    if (defined $settings->{schema}) {
-        if (blessed $settings->{schema}) {
-            $handle->{schema} = $settings->{schema};
+    if ( my $schema = $settings->{schema}) {
+        if (blessed $schema) {
+            $handle->{schema} = $schema;
+        }
+        elsif( ref $schema ) {
+            $handle->{schema} = $schema->();
         }
         else {
-            $handle->{schema} = $settings->{schema}->();
+            die "can't use named schema: Dancer::Plugin::DBIC not loaded\n"
+                unless $Dancer::Plugin::DBIC::VERSION;
+            $handle->{schema} = Dancer::Plugin::DBIC::schema($schema);
         }
     }
     elsif (! defined $settings->{schema_class}) {
@@ -241,7 +288,7 @@ sub _serialize {
 
     # A session is by definition ephemeral - Store it compactly
     # This is the Dancer function, not from JSON.pm
-    return to_json({%$self}, { pretty => 0 });
+    return to_json({%$self}, { pretty => 0, convert_blessed => 1 });
 }
 
 
@@ -271,6 +318,11 @@ Stefan Hornburg (Racke) <racke@linuxia.de>
 Based on code from L<Dancer::Session::DBI> written by James Aitken
 and code from L<Dancer::Plugin::DBIC> written by Naveed Massjouni.
 
+Enhancements provided by:
+
+Yanick Champoux (GH #6, #7).
+Peter Mottram (GH #5).
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) Stefan Hornburg.
